@@ -12,7 +12,7 @@ autoplot <- function (object, ...){
 ##' @export
 ##' 
 ##' @title Generate a \code{ggplot} for an \code{rpart} object
-##' @description Uses \code{ggplot2} to render a recursive partitioning tree.
+##' @description Uses \code{ggplot2} to render a recursive partitioning tree
 ##' 
 ##' @include genSurv.R
 ##' 
@@ -105,28 +105,22 @@ autoplot <- function (object, ...){
 ##'   \item{plot}{A plot, as generated by \code{ggplot}}
 ##'   \item{segments}{A \code{data.table} with the co-ordinates used to plot the lines}
 ##'   \item{nodes}{A \code{data.table} with the co-ordinates used to plot the nodes.
-##'                \cr
-##'                Columns are labelled as follows:
-##'                \describe{
-##'                  \item{x, y}{\eqn{x} and \eqn{y} co-ordinates}
-##'                  \item{node}{Node name}
-##'                  \item{n}{Number of observations (number at risk) for this node}
-##'                  \item{isP}{Is node a \bold{p}arent?}
-##'                  \item{lC, rC}{Left and right \bold{c}hildren of node}
-##'                  \item{isL}{Is node a \bold{l}eaf (terminal node)?}
-##'                  \item{resp}{Predicted \bold{resp}onse}
-##'                  \item{yNU, yND, yLD}{adjusted \eqn{y} values for
-##'                                       \cr
-##'                                       \bold{n}odes (\bold{u}p and \bold{d}down) and
-##'                                       \cr
-##'                                       \bold{l}eaves (\bold{d}own)}
-##'                }
-##'                And where applicable:
-##'                \describe{
-##'                  \item{e}{Number of events}
-##'                  \item{en}{Number of events / number of observations}
-##'                }
-##'   }
+##'   Columns are labelled as follows:
+##'  \describe{
+##'  \item{x, y}{\eqn{x} and \eqn{y} co-ordinates}
+##'  \item{node}{Node name}
+##'  \item{n}{Number of observations (number at risk) for this node}
+##'  \item{isP}{Is node a \bold{p}arent?}
+##'  \item{lC, rC}{Left and right \bold{c}hildren of node}
+##'  \item{isL}{Is node a \bold{l}eaf (terminal node)?}
+##'  \item{resp}{Predicted \bold{resp}onse}
+##'  \item{yNU, yND, yLD}{adjusted \eqn{y} values for \bold{n}odes (\bold{u}p and \bold{d}down) and \bold{l}eaves (\bold{d}own)}
+##'  }
+##'  And where applicable:
+##' \describe{
+##'  \item{e}{Number of events}
+##'  \item{en}{Number of events / number of observations}
+##'  }}
 ##' }
 ##' 
 ##' @details The plot shows a division at each node. This is read as \emph{right=TRUE}.
@@ -138,12 +132,12 @@ autoplot <- function (object, ...){
 ##' 
 ##' @examples
 ##' data("cu.summary", package="rpart")
-##' fit <- rpart::rpart(Price ~ Mileage + Type + Country, data=cu.summary)
+##' fit <- rpart::rpart(Price ~ Mileage + Type + Country, cu.summary)
 ##' autoplot(fit)
 ##' data("stagec", package="rpart")
 ##' progstat <- factor(stagec$pgstat, levels = 0:1, labels = c("No", "Prog"))
 ##' cfit <- rpart::rpart(progstat ~ age + eet + g2 + grade + gleason + ploidy,
-##'                      data=stagec, method="class")
+##'                      data = stagec, method = 'class')
 ##' autoplot(cfit)
 ##' set.seed(1)
 ##' df1 <- genSurvDf(model=FALSE)
@@ -151,7 +145,7 @@ autoplot <- function (object, ...){
 ##' autoplot(r1, leaf="en", title="Nodes show events / no. at risk")
 ##' autoplot(r1, compress=TRUE, branch=0.5, nspace=0.1,
 ##'          title="Nodes show events / no. at risk")
-##' ### oversize text; need to adjust y values for text to compensate
+##' ### oversize text; need to adjust 'y' values for text to compensate
 ##' a1 <- autoplot(r1, compress=TRUE, digits=5,
 ##'                nodeSize=10, yNU=0.05, yND=0.03,
 ##'                leafSize=10, , yLD=0.08, nodeLabels=seq(17))$plot
@@ -179,6 +173,10 @@ autoplot.rpart <- function(object,
                            yNU=0.02,
                            yND=0.02,
                            yLD=0.02){
+### prevent errors in R CMD check
+    ind <- x <- y <- V5 <- e <- n <- resp <- NULL
+    xend <- yend <- yM <- ym <- en <- respEN <- NULL
+###
     if (!inherits(object, "rpart")) stop("Not a legitimate \"rpart\" object")
     if (nrow(object$frame) <= 1L) stop("Fit is not a tree, just a root")
     if (!missing(nspace) & !compress) warning("nspace not used unless compress=TRUE")
@@ -213,7 +211,7 @@ autoplot.rpart <- function(object,
                 rp1$y[sibling],
                 NA)
 ### get segments from xx, yy
-    d1 <- data.table::data.table(
+    d1 <- data.table(
         stack(as.data.frame(xx)),
         stack(as.data.frame(yy))
         )[, ind := NULL]
@@ -243,8 +241,7 @@ autoplot.rpart <- function(object,
     d2[, "V6" := left.child]
     d2[, "V7" := right.child]
     d2[, "V8" := !V5]
-    data.table::setnames(d2,
-                         c("x", "y", "node", "n", "isP", "lC", "rC", "isL"))
+    setnames(d2, c("x", "y", "node", "n", "isP", "lC", "rC", "isL") )
 ### does second value for y exist?
     y2e <- "yval2" %in% names(object$frame)
     if(y2e & object$method=="exp") {
@@ -316,7 +313,7 @@ autoplot.rpart <- function(object,
 ###
 ###----------------------------------------
 ### copied from rpart:::rpartco
-### with minor changes to formatting and indenting
+### minor changes to formatting and indenting
 ###----------------------------------------
 ###
 .rpco <- function (tree, parms) {
